@@ -3,16 +3,24 @@ from pathlib import PurePath
 class LoggingConstants:
     def __init__(self):
         #main logging config
-        self.CURRENTPATH = os.path.dirname(os.path.realpath(__file__))
-        self.CURRENTPATH = PurePath(self.CURRENTPATH)
-        self.PARENTPATH = self.CURRENTPATH.parents[0]
+        # if on a unix type system with /var/log put the logs there
+        if os.path.isdir('/var/log'):
+            self.PARENTPATH = '/var'
+            self.LOGDIRECTORY = 'log'
+        else:
+            # determine the log path the old way under the execution path
+            self.CURRENTPATH = os.path.dirname(os.path.realpath(__file__))
+            self.CURRENTPATH = PurePath(self.CURRENTPATH)
+            self.PARENTPATH = str(self.CURRENTPATH.parents[0])
+            self.LOGDIRECTORY = 'logs'
+
         self.LOGFORMAT = '%(levelname)s : %(asctime)s : %(filename)s:%(lineno)d : %(message)s'
         self.LOGNAME = 'FTS'
-        self.LOGDIRECTORY = 'logs'
-        self.WARNINGLOG = PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_warning.log")
-        self.DEBUGLOG = PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_debug.log")
-        self.INFOLOG = PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_info.log")
-        self.HTTPLOG = PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_http.log")
+
+        self.ERRORLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_error.log"))
+        self.DEBUGLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_debug.log"))
+        self.INFOLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_info.log"))
+        self.HTTPLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_http.log"))
         self.DELIMITER = ' ? '
         self.MAXFILESIZE = 100000
         self.BACKUPCOUNT = 5
@@ -123,4 +131,4 @@ class LoggingConstants:
         #XMLCoTController
         #determine CoT general
         self.XMLCOTCONTROLLERDETERMINECOTGENERALERRORA = "exception XMLCoTController in determining general CoT type A "
-        self.XMLCOTCONTROLLERDETERMINECOTGENERALERRORB = "exception XMLCoTController in determining general CoT type B "
\ No newline at end of file
+        self.XMLCOTCONTROLLERDETERMINECOTGENERALERRORB = "exception XMLCoTController in determining general CoT type B "
