@@ -13,6 +13,7 @@ class ContactVariables:
         cls.ICONSETPATH = None
         cls.UID = None
         cls.NAME = None
+        cls.PHONE = None
         return cls
 
     @classmethod
@@ -61,5 +62,25 @@ class ContactVariables:
 
     @classmethod
     def Route(cls):
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def VideoStream(cls):
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def DroneSensor(cls):
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def SPISensor(cls):
+        cls.callsign = None
+        return cls
+
+    @classmethod
+    def BitsImageryVideo(cls):
         cls.callsign = None
         return cls
\ No newline at end of file
